selectedBorderWidth property
The selectedBorderWidth param specifies the width of the border around the selected cover thumbnail
Implementation
final double selectedBorderWidth;
The selectedBorderWidth param specifies the width of the border around the selected cover thumbnail
final double selectedBorderWidth;